<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label="体检号" prop="tjNumber">
        <el-input ref="inputName" v-model="queryParams.tjNumber" placeholder="请输入体检号" clearable
          @keyup.enter.native="handleQuery" />
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <!-- <el-col :span="1.5">
        <el-button type="primary" plain icon="el-icon-plus" size="mini" @click="handleAdd"
          v-hasPermi="['system:report:add']">新增</el-button>
      </el-col> -->
      <!-- <el-col :span="1.5">
        <el-button type="success" plain icon="el-icon-edit" size="mini" :disabled="single" @click="handleUpdate"
          v-hasPermi="['system:report:edit']">修改</el-button>
      </el-col> -->
      <!-- <el-col :span="1.5">
        <el-button type="danger" plain icon="el-icon-delete" size="mini" :disabled="multiple" @click="handleDelete"
          v-hasPermi="['system:report:remove']">删除</el-button>
      </el-col> -->
      <el-col :span="1.5">
        <el-button type="warning" plain icon="el-icon-download" size="mini" @click="handleExport"
          v-hasPermi="['system:report:export']">导出</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="reportList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column label="序号" align="center" prop="nweID" />
      <!-- <el-table-column label="主键" align="center" prop="reId" /> -->
      <!-- <el-table-column label="报告存储" align="center" prop="report" /> -->
      <el-table-column label="体检号" align="center" prop="tjNumber" />
      <el-table-column label="体检报告" align="center">
        <template>
          <el-link @click="preview"><i class="el-icon-view el-icon--right"> 查看</i> </el-link>&nbsp;&nbsp;&nbsp;&nbsp;
          <!-- <el-link icon="el-icon-edit" @click="downLoad"
            v-hasPermi="['system:report:export']">下载</el-link>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; -->
          <a href="blob:http://localhost:81/27567430-146b-4ab0-ba52-7e17220035a6" download="12212145360.pdf">下载模板</a>
        </template>
      </el-table-column>

      <el-table-column label="路径（不要了，后期改成别的）" align="center" prop="path" />
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <!-- <el-button size="mini" type="text" icon="el-icon-edit" @click="handleUpdate(scope.row)"
            v-hasPermi="['system:report:edit']">修改</el-button> -->
          <el-button size="mini" type="text" icon="el-icon-delete" @click="handleDelete(scope.row)"
            v-hasPermi="['system:report:remove']">删除</el-button>
        </template>
      </el-table-column>
    </el-table>

    <div class="pag">
      <div class="pag1">
        <pagination v-show="total > 0" :total="total" :page.sync="queryParams.pageNum" :limit.sync="queryParams.pageSize"
          @pagination="getList" />
      </div>
    </div>
    <!-- 添加或修改体检报告存储对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="报告存储">
          <file-upload v-model="form.report" />
        </el-form-item>
        <el-form-item label="体检号" prop="tjNumber">
          <el-input v-model="form.tjNumber" placeholder="请输入体检号" />
        </el-form-item>
        <el-form-item label="路径" prop="path">
          <el-input v-model="form.path" placeholder="请输入路径" />
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>

    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <!-- <image style="width: 100px; height: 100px" :src="mapSrc" /> -->
      <img :src="mapSrc" alt="">
    </el-dialog>
  </div>
</template>

<script>
import { listReport, getReport, delReport, addReport, updateReport, getToPdf, getpreview } from "@/api/system/report";

export default {
  name: "Report",
  data() {
    return {
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 体检报告存储表格数据
      reportList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      mapSrc: "0",
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        tjNumber: null,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
      }
    };
  },
  created() {
    this.getList();
  },
  methods: {
    /** 查询体检报告存储列表 */
    getList() {
      this.$nextTick(() => {
        this.$refs.inputName.focus()
        this.$forceUpdate()
      })
      this.loading = true;
      listReport(this.queryParams).then(response => {
        this.reportList = response.rows;
        for (let i = 0; i < response.rows.length; i++) {
          response.rows[i].nweID = i + 1;
        }
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        reId: null,
        // report: null,
        tjNumber: null,
        path: null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
      // this.$confirm('此操作将永久删除该文件, 是否继续?', '提示', {
      //   confirmButtonText: '确定',
      //   cancelButtonText: '取消',
      //   type: 'warning'
      // }).then(() => {
      //   this.$message({
      //     type: 'success',
      //     message: '删除成功!'
      //   });
      // }).catch(() => {
      //   this.$message({
      //     type: 'info',
      //     message: '已取消删除'
      //   });          
      // });

    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },

    // 查看
    preview() {
      let tjNumber = 12212145360
      getToPdf(tjNumber).then(response => {
        this.open = true
        let blob = new Blob([response.msg])
        let url = window.URL.createObjectURL(blob)
        this.mapSrc = url
        // this.reportList = response.rows;
      });
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.reId)
      this.single = selection.length !== 1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加体检报告存储";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const reId = row.reId || this.ids
      getReport(reId).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = "修改体检报告存储";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.reId != null) {
            updateReport(this.form).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addReport(this.form).then(response => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const reIds = row.reId || this.ids;
      this.$modal.confirm('是否确认删除体检报告存储编号为"' + reIds + '"的数据项？').then(function () {
        return delReport(reIds);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).catch(() => { });
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download('system/report/export', {
        ...this.queryParams
      }, `report_${new Date().getTime()}.xlsx`)
    },
    // 下载按钮操作
    downLoad() {
      let tjNumber = 12212145360
      getToPdf(tjNumber).then(response => {
        this.open = true
        let blob = new Blob([response.msg])
        let url = window.URL.createObjectURL(blob)
        this.mapSrc = url
        // this.reportList = response.rows;
      });
    },

  }

};
</script>
<style scoped>
.pag {
  width: 100%;
  display: flex;
  justify-content: center;
}

.pag1 {
  width: 30%;
}
</style>
